@@ -2,10 +2,12 @@ package Acme::MetaSyntactic::magicroundabout;
 use strict;
 use Acme::MetaSyntactic::Locale;
 our @ISA = qw( Acme::MetaSyntactic::Locale );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 __PACKAGE__->init();
 1;
 
+=encoding iso-8859-1
+
 =head1 NAME
 
 Acme::MetaSyntactic::magicroundabout - The Magic Round-About theme
@@ -23,6 +25,9 @@ Introduced in Acme-MetaSyntactic version 0.24, published on May 30, 2005.
 Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
 published on May 7, 2012.
 
+Updated with an C<=encoding> pod command in version 1.001,
+published on May 14,2012
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.
